@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __GPK_ENUM_H
@@ -55,11 +55,21 @@ typedef enum {
 	GPK_INFO_ENUM_UNKNOWN
 } GpkInfoStatusEnum;
 
-/* constants defined in 0.5.6 */
+/* constants defined in previous versions */
 #if (!PK_CHECK_VERSION(0,5,6))
 #define PK_ERROR_ENUM_UPDATE_FAILED_DUE_TO_RUNNING_PROCESS		(PK_ERROR_ENUM_PACKAGE_FAILED_TO_REMOVE + 1)
 #endif
 
+#if (!PK_CHECK_VERSION(0,5,7))
+#define PK_MESSAGE_ENUM_REPO_FOR_DEVELOPERS_ONLY			(PK_MESSAGE_ENUM_REPO_METADATA_DOWNLOAD_FAILED + 1)
+#endif
+
+#if (!PK_CHECK_VERSION(0,6,2))
+#define PK_CLIENT_ERROR_DECLINED_SIMULATION				 PK_CLIENT_ERROR_FAILED
+#define PK_ERROR_ENUM_PACKAGE_DATABASE_CHANGED				 PK_ERROR_ENUM_ENUM_LAST
+#define PK_CLIENT_ERROR_LAST						(PK_CLIENT_ERROR_DECLINED_SIMULATION + 1)
+#endif
+
 void		 gpk_enum_test				(gpointer	 data);
 const gchar	*gpk_role_enum_to_localised_past	(PkRoleEnum	 role)
 							 G_GNUC_CONST;
